#!/usr/bin/env python3

import os

from configparser import ConfigParser

#___________________________________________________________________
def config(home='~/'):
	'''
	return a dict of the .aws files { profile: { key: value }	}
	'''
	
	parser = ConfigParser()

	for file in ['credentials','config']:
		dot_aws = os.path.expanduser('%s/.aws/%s'%(home,file))
		if os.path.exists(dot_aws):
			parser.read(dot_aws)	
				
	result = dict.fromkeys(parser.sections())
	for key in result.keys():
		result[key] = dict()
		for (name,value) in parser.items(key):
			result[key][name] = value

	return result




#!/usr/bin/env python

import re, os, sys, socket, paramiko

from Tools.Squirrel import Squirrel

squirrel = Squirrel()


class MySSH(object):
	def __init__(self, username, hostname, password=None, port=22, key=None):
		
		# force ip4 host connect
		sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
		sock.connect((hostname, port))
		
		self.client = paramiko.SSHClient()		
		self.client.load_system_host_keys()
		self.client.set_missing_host_key_policy(
			paramiko.AutoAddPolicy()
		)
		
		if key:
			privateKey = paramiko.RSAKey.from_private_key_file(
				os.path.expanduser(key), password=password
			)
			self.client.connect(
				hostname,
				sock=sock,
				port=port, 
				username=username,
				pkey=privateKey,
				timeout=5,
			)
		else:
			self.client.connect(
				hostname, 
				sock=sock,
				port=port, 
				username=username, 
				password=password, 
				timeout=5,
			)

	def __del__(self):
		self.close()

	def close(self):
		self.client.close()

	def execute(self, command):
		print('$ %s' % command)
		stdin, stdout, stderr = self.client.exec_command(command)
		sys.stderr.write(stderr.read())
		return stdout.read()


def main():
	username = 'ubuntu'
	hostname = 'pocketrocketsoftware.com'
	password = squirrel.get('ssh:%s:%s'%(
		username,
		hostname,
	)) 
	key = '~/.ssh/id_rsa'
	mySSH = MySSH(
		username, 
		hostname, 
		key=key, 
		password=password,
	)
	print(mySSH.execute('uptime'))
	#print(mySSH.execute('cd ~/tmp; ls -s;'))
	mySSH.close()


if __name__ == '__main__': main()
	



#!/usr/bin/env python3

# PYTHON_ARGCOMPLETE_OK

import sys, re, os, json

sys.path.append('..')

from Baubles.Logger import Logger
from Argumental.Argue import Argue
from Perdy.pretty import prettyPrintLn, Style

from CloudyDaze.MyAWS import config
from CloudyDaze.MyEC2 import MyEC2, args

print(json.dumps(args.execute(), indent=4))




#!/usr/bin/env python3

# PYTHON_ARGCOMPLETE_OK

import sys, re, os, json

sys.path.append('..')

from Baubles.Logger import Logger
from Argumental.Argue import Argue

from CloudyDaze.MyAWS import config
from CloudyDaze.MySG import MySG, args

args.execute()
